==> nebula-core-1.2.3.10-Release-sources.jar: com/bizunited/platform/core/controller/dataview/DataViewGroupController.java <==
package com.bizunited.platform.core.controller.dataview;

import com.alibaba.fastjson.JSONObject;
import com.bizunited.platform.core.controller.BaseController;
import com.bizunited.platform.core.controller.model.ResponseModel;
import com.bizunited.platform.core.entity.DataViewGroupEntity;
import com.bizunited.platform.core.service.dataview.DataViewGroupService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * DataViewGroupEntity业务模型的MVC Controller层实现，基于HTTP Restful风格
 * @author saturn
 */
@RestController
@RequestMapping("/v1/nebula/dataViewGroups")
public class DataViewGroupController extends BaseController {
  /**
   * 日志
   */
  private static final Logger LOGGER = LoggerFactory.getLogger(DataViewGroupController.class);
  
  @Autowired
  private DataViewGroupService dataViewGroupEntityService;

  /**
   * 相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）
   * */
  @ApiOperation(value = "相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）")
  @PostMapping(value="")
  public ResponseModel create(@RequestBody @ApiParam(name="dataViewGroupEntity" , value="相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）") DataViewGroupEntity dataViewGroupEntity) {
    try {
      DataViewGroupEntity current = this.dataViewGroupEntityService.create(dataViewGroupEntity , false);
      return this.buildHttpReslutW(current, new String[]{});
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    }
  }

  /**
   * 相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）
   * */
  @ApiOperation(value = "相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）")
  @PatchMapping(value="")
  public ResponseModel update(@RequestBody @ApiParam(name="dataViewGroupEntity" , value="相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）") DataViewGroupEntity dataViewGroupEntity) {
    try {
      DataViewGroupEntity current = this.dataViewGroupEntityService.update(dataViewGroupEntity);
      return this.buildHttpReslutW(current, new String[]{});
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    }
  }

  /**
   * 按照数据源ID查询DataViewGroupEntity
   */
  @ApiOperation(value = "按照数据源id查询DataViewGroupEntity")
  @RequestMapping(value="/findByDataSource" , method={RequestMethod.GET})
  public ResponseModel findByDataSource(@RequestParam("dataSourceId") @ApiParam("数据源id") String dataSourceId) {
    try {
      List<DataViewGroupEntity> result = this.dataViewGroupEntityService.findByDataSource(dataSourceId);
      return this.buildHttpReslutW(result, new String[]{"dataSource"});
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    } 
  } 
  
  
  /**
   * 按照数据源ID查询DataViewGroupEntity详情
   * 该接口用于返回前端特定的数据类型，展示视图分组信息
   */
  @ApiOperation(value = "按照数据源id查询DataViewGroupEntity详情")
  @RequestMapping(value="/findDetailsByDataSource" , method={RequestMethod.GET})
  public ResponseModel findDetailsByDataSource(@RequestParam(required=false) @ApiParam("数据源id") String dataSourceId) {
    try {
      List<JSONObject> result = this.dataViewGroupEntityService.findDetailsByDataSource(dataSourceId);
      return this.buildHttpReslutW(result, new String[]{});
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    } 
  } 
  
  
  /**
   * 按照主键进行查询明细查询，查询的明细包括当前业务表单所有的关联属性。
   * @param id 主键
   */
  @ApiOperation(value = "按照主键进行查询明细查询，查询的明细包括当前业务表单所有的关联属性。")
  @RequestMapping(value="/findDetailsById" , method={RequestMethod.GET})
  public ResponseModel findDetailsById(@RequestParam(value="id") @ApiParam("主键") String id) {
    try { 
      DataViewGroupEntity result = this.dataViewGroupEntityService.findDetailsById(id); 
      return this.buildHttpReslutW(result, new String[]{"dataSource"}); 
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    } 
  }


  /**
   *
   * @param dataViewId
   * @param dataViewGroupId
   * @return
   */
  @ApiOperation(value = "将某视图移动至新的分组下")
  @RequestMapping(value="/moveGroup" , method={RequestMethod.PATCH})
  public ResponseModel moveGroup(@RequestParam("dataViewId") @ApiParam("数据视图ID") String dataViewId,@RequestParam("dataViewGroupId") @ApiParam("移至分组ID") String dataViewGroupId) {
    try {
      this.dataViewGroupEntityService.moveGroup(dataViewId,dataViewGroupId);
      return this.buildHttpReslut();
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpReslutForException(e);
    }
  }

}

==> nebula-core-2.0.2.11-Release-sources.jar: com/bizunited/platform/core/controller/dataview/DataViewGroupController.java <==
package com.bizunited.platform.core.controller.dataview;

import com.alibaba.fastjson.JSONObject;
import com.bizunited.platform.core.controller.BaseController;
import com.bizunited.platform.core.controller.model.ResponseModel;
import com.bizunited.platform.core.entity.DataViewGroupEntity;
import com.bizunited.platform.core.service.dataview.DataViewGroupService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * DataViewGroupEntity业务模型的MVC Controller层实现，基于HTTP Restful风格
 * @author saturn
 */
@RestController
@RequestMapping("/v1/nebula/dataViewGroups")
public class DataViewGroupController extends BaseController {
  /**
   * 日志
   */
  private static final Logger LOGGER = LoggerFactory.getLogger(DataViewGroupController.class);
  
  @Autowired
  private DataViewGroupService dataViewGroupEntityService;

  /**
   * 相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）
   * */
  @ApiOperation(value = "相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）")
  @PostMapping(value="")
  public ResponseModel create(@RequestBody @ApiParam(name="dataViewGroupEntity" , value="相关的创建过程，http接口。请注意该创建过程除了可以创建dataViewGroupEntity中的基本信息以外，还可以对dataViewGroupEntity中属于OneToMany关联的明细信息一同进行创建注意：创建操作传入的dataViewGroupEntityJSON对象，其主键信息不能有值，服务端将会自动为其赋予相关值。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）") DataViewGroupEntity dataViewGroupEntity) {
    try {
      DataViewGroupEntity current = this.dataViewGroupEntityService.create(dataViewGroupEntity , false);
      return this.buildHttpResultW(current);
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    }
  }

  /**
   * 相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）
   * */
  @ApiOperation(value = "相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）")
  @PatchMapping(value="")
  public ResponseModel update(@RequestBody @ApiParam(name="dataViewGroupEntity" , value="相关的更新过程，http接口。请注意该更新过程只会更新在模型层被标记为了updateable的属性，包括一般属性、ManyToOne和OneToOne性质的关联属性，而ManyToMany、OneToMany的关联属性，虽然也会传入，但需要开发人员自行在Service层完善其更新过程注意：修改操作传入的dataViewGroupEntityJSON对象，其主键信息必须有值，服务端将验证这个主键值是否已经存在。另外，创建操作成功后，系统将返回该对象的基本信息（不包括任何关联信息）") DataViewGroupEntity dataViewGroupEntity) {
    try {
      DataViewGroupEntity current = this.dataViewGroupEntityService.update(dataViewGroupEntity);
      return this.buildHttpResultW(current);
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    }
  }

  /**
   * 按照数据源ID查询DataViewGroupEntity
   */
  @ApiOperation(value = "按照数据源id查询DataViewGroupEntity")
  @RequestMapping(value="/findByDataSource" , method={RequestMethod.GET})
  public ResponseModel findByDataSource(@RequestParam("dataSourceId") @ApiParam("数据源id") String dataSourceId) {
    try {
      List<DataViewGroupEntity> result = this.dataViewGroupEntityService.findByDataSource(dataSourceId);
      return this.buildHttpResultW(result, "dataSource");
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    } 
  } 
  
  
  /**
   * 按照数据源ID查询DataViewGroupEntity详情
   * 该接口用于返回前端特定的数据类型，展示视图分组信息
   */
  @ApiOperation(value = "按照数据源id查询DataViewGroupEntity详情")
  @RequestMapping(value="/findDetailsByDataSource" , method={RequestMethod.GET})
  public ResponseModel findDetailsByDataSource(@RequestParam(required=false) @ApiParam("数据源id") String dataSourceId) {
    try {
      List<JSONObject> result = this.dataViewGroupEntityService.findDetailsByDataSource(dataSourceId);
      return this.buildHttpResultW(result);
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    } 
  } 
  
  
  /**
   * 按照主键进行查询明细查询，查询的明细包括当前业务表单所有的关联属性。
   * @param id 主键
   */
  @ApiOperation(value = "按照主键进行查询明细查询，查询的明细包括当前业务表单所有的关联属性。")
  @RequestMapping(value="/findDetailsById" , method={RequestMethod.GET})
  public ResponseModel findDetailsById(@RequestParam(value="id") @ApiParam("主键") String id) {
    try { 
      DataViewGroupEntity result = this.dataViewGroupEntityService.findDetailsById(id); 
      return this.buildHttpResultW(result, "dataSource");
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    } 
  }


  /**
   *
   * @param dataViewId
   * @param dataViewGroupId
   * @return
   */
  @ApiOperation(value = "将某视图移动至新的分组下")
  @RequestMapping(value="/moveGroup" , method={RequestMethod.PATCH})
  public ResponseModel moveGroup(@RequestParam("dataViewId") @ApiParam("数据视图ID") String dataViewId,@RequestParam("dataViewGroupId") @ApiParam("移至分组ID") String dataViewGroupId) {
    try {
      this.dataViewGroupEntityService.moveGroup(dataViewId,dataViewGroupId);
      return this.buildHttpResult();
    } catch(Exception e) {
      LOGGER.error(e.getMessage() , e);
      return this.buildHttpResultForException(e);
    }
  }

}
